# Bun bun-v0.0.79 — Release & Upgrade Intelligence
- **Product:** Bun (https://bun.sh)
- **Version:** bun-v0.0.79
- **Released:** May 04, 2022
- **Impact Score:** 7/10
- **Breaking Changes:** Source flagged
- **Canonical Analysis:** https://changelogs.us/bun/updates/bun-v0.0.79/

## Executive Summary (TL;DR)
Bun bun-v0.0.79. Source highlight: If you run into any issues with upgrading

## Breaking Changes & Deprecations
- - `Buffer` (like in Node.js) is now a global, but the implementation is incomplete - [see tracking issue](https://github.com/Jarred-Sumner/bun/issues/155). If you import `"buffer"`, it continues to use the browser polyfill so this shouldn't be a breaking change

## New Features
- @jameslahm [[node] Add more fs constants](https://github.com/Jarred-Sumner/bun/commit/64a2dda02f7647a506c22057fd4659bd8856ea08)
- [[bun.js] Add Bun.nanoseconds() to report time in nanos](https://github.com/Jarred-Sumner/bun/commit/69668d49e5ddb5169eae7966d8a30e9ae9e32cea)

## Bug Fixes
- 2x faster `TextEncoder` & `TextDecoder` thanks to some fixes to the vectorization (SIMD) code
- Faster `TypedArray.from`. JavaScriptCore's implementation of `TypedArray.from` uses the code path for JS iterators when it could instead use an optimized code path for copying elements from an array, like V8 does. I have filed an upstream bug with WebKit about this, but I expect to do a more thorough fix for this in Bun and upstream that. For now, Bun reuses `TypedArray.prototype.set`  when possible
- Fixed a reliability bug with `new Response(Bun.file(path))`
- [[bun.js] Fix bug with readdirSync on folders with less than 32 files](https://github.com/Jarred-Sumner/bun/commit/f2c21b77336b9dcfa90676670877790ee48b31cc)
- [[bun dev] Fix CSS HMR bug](https://github.com/Jarred-Sumner/bun/commit/1788503892d27027b584542c2966daac06308c93)
- [[JS Parser] Fix overly-eager CJS -> ESM transform](https://github.com/Jarred-Sumner/bun/commit/ea241fcec7add6187ec915ed0b3983f3be0529f9)
